@@ -1,6 +1,9 @@
 '''
 This script finds the mean chat_rate per unique user per `min_` min chunk,
 isolates to each `min_` timestamp, and sorts the resulting df by largest number
+
+HOW TO
+    algo2.run(data, min_=2, save_json = False)
 '''
 import pandas as pd
 import datetime as dt
@@ -34,7 +37,7 @@ def thalamus(dataframe, min_):
 
     # for each 2 min chunk
     for chunk in chunk_list:
-        hour = chunk.iloc[-1,12] # col 12 is hour.
+        hour = chunk.iloc[-1,11] # col 11 is hour.
         # find the chat rate for each user
         chat_rates = chat_rates.append(rate_finder(dataframe = chunk, hour = hour, x=2)) 
 
